@@ -14,15 +14,12 @@
 #include <QClipboard>
 #include <QDebug>
 #include <QMimeData>
-#include <QTextDocument>
 #include <QAbstractTextDocumentLayout>
-#include <QTextCursor>
 #include <QTextBlock>
 #include <QTextLine>
 #include <QGraphicsSceneResizeEvent>
 #include <QPainter>
 
-#include <KStandardAction>
 #include <QAction>
 #include <QColorDialog>
 #include <KColorScheme>
@@ -191,9 +188,10 @@ void WorksheetTextItem::copy()
         QApplication::sendEvent(worksheet(), event);
         delete event;
     } else {
-        if (!textCursor().hasSelection())
-            return;
-        QString text = resolveImages(textCursor());
+        auto cursor = textCursor();
+        if (!cursor.hasSelection())
+            cursor.select(QTextCursor::Document);
+        QString text = resolveImages(cursor);
         text.replace(QChar::ParagraphSeparator, QLatin1Char('\n'));
         text.replace(QChar::LineSeparator, QLatin1Char('\n'));
         QApplication::clipboard()->setText(text);
